import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

// Data set URI
const csvUrl = 'https://gist.githubusercontent.com/Prathyusha0304/c26636860e32a1e0c08ac973192e41e6/raw/c1d2b9ce3b010cda19dce306c2fc15a1142fae10/Dataset1.csv';  

// Format the Data from the URI response
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  
  // Creating a new Scatter Plot object
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 30,
      right: 10,
      bottom: 60,
      left: 80,
    })
    .radius(10);

  // Plotting the Scatter Plot axes based on the given parameters
  svg.call(plot);

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  
  // Plotting the data on the Scatter Plot
  let i = 0;
 	plot.xValue((d) => d[columns[i % columns.length]]);
  svg.call(plot);
};
main();



